import {FlexAlignType, View, ViewProps} from 'react-native';

const _alignX: {
    [key: string]:
        | 'flex-start'
        | 'flex-end'
        | 'center'
        | 'space-between'
        | undefined
} = {
    'start': 'flex-start',
    'center': 'center',
    'end': 'flex-end',
    'space': 'space-between',
};

const _alignY: { [key: string]: FlexAlignType } = {
    'start': 'flex-start',
    'center': 'center',
    'end': 'flex-end',
};

export type RowProps = ViewProps & {
    fullWidth?: boolean | undefined,
    alignX?: 'start' | 'center' | 'end' | 'space' | undefined,
    alignY?: 'start' | 'center' | 'end' | undefined,
}

export default function Row(props: RowProps): JSX.Element {
    const {fullWidth, alignX, alignY, style, ...otherProps} = props;

    return (
        <View {...otherProps} style={[{
            flexDirection: 'row',
            width: fullWidth ? '100%' : undefined,
            alignItems: _alignY[alignY],
            justifyContent: _alignX[alignX],
        }, style]}/>
    );
}