import {Dimensions} from 'react-native';
import * as React from "react";

export type initUseLayoutProps = {
    targetWidth: number,
    targetHeight: number,
}

export type useLayoutResultProps = {
    deviceWidth: number,
    deviceHeight: number,
    rw: (w: number) => number,
    rh: (h: number) => number,
};

export default function initUseLayout(props: initUseLayoutProps) {
    return function useLayout(): useLayoutResultProps {
        const {targetWidth, targetHeight} = props;

        const [deviceWidth, setDeviceWidth] = React.useState(Dimensions.get('window').width);
        const [deviceHeight, setDeviceHeight] = React.useState(Dimensions.get('window').height);

        React.useEffect(() => {
            const listener = Dimensions.addEventListener('change', ({window: {width, height}}) => {
                setDeviceWidth(width);
                setDeviceHeight(height);
            });

            return () => {
                listener.remove();
            }
        }, []);

        return {
            deviceWidth,
            deviceHeight,
            rw: (w) => {
                return Number((w / targetWidth * deviceWidth).toFixed(0));
            },
            rh: (h) => {
                return Number((h / targetHeight * deviceHeight).toFixed(0));
            },
        }
    };
}