import * as React from "react";
import useStorage from "./useStorage";

export type initUseThemeProps = {
    themes: { [key: string]: any }[],
    defaultThemeKey: string,
}

export type useThemeResultProps = [
    theme: { [key: string]: any },
    setTheme: (key: string) => void,
    reloadTheme: () => void,
];

export default function initUseTheme(props: initUseThemeProps) {
    return function useTheme(): useThemeResultProps {
        const [themeKey, setThemeKey, reloadThemeKey] = useStorage('irnc-theme-key', props.defaultThemeKey);
        const [theme, setTheme] = React.useState(props.themes[themeKey]);

        React.useEffect(() => {
            setTheme(props.themes[themeKey]);
        }, [themeKey]);

        return [
            theme,
            setThemeKey,
            reloadThemeKey,
        ]
    };
}