import * as React from 'react';
import {DependencyList, EffectCallback} from "react";

type AsyncEffectCallback = () => Promise<void>;

/**
 * Accepts a function that contains imperative, possibly effectful code.
 *
 * @param func Imperative function that can return a cleanup function
 * @param deps If present, effect will only activate if the values in the list change.
 */
export default function useAsyncEffect(func: EffectCallback | AsyncEffectCallback, deps?: DependencyList): void {
    React.useEffect(() => {
        (async () => {
            await func();
        })();
    }, deps);
};