import AsyncStorage from '@react-native-async-storage/async-storage';
import * as React from 'react';
import useAsyncEffect from './useAsyncEffect';

export type StorageResultProps = [
    value: any,
    setter: (value: string) => Promise<void>,
    reload: () => Promise<void>,
]

export default function useStorage(key: string, defaultValue?: any): StorageResultProps {
    const [value, setValue] = React.useState(defaultValue);

    const getter = React.useCallback(async () => {
        try {
            const jsonValue = await AsyncStorage.getItem(key);
            return JSON.parse(jsonValue);
        } catch (e) {
            return defaultValue;
        }
    }, [key]);

    const setter = React.useCallback(async (value: string) => {
        try {
            const jsonValue = JSON.stringify(value);
            await AsyncStorage.setItem(key, jsonValue);
            setValue(value);
        } catch (e) {
            console.log(e);
        }
    }, [key]);

    useAsyncEffect(async () => {
        setValue(await getter());
    }, [key]);

    return [value, setter, async () => {
        const _value = await getter();

        if (value !== _value) {
            setValue(_value);
        }
    }];
}